# This file is part of the standard testthat package layout.
# It is the entry point used by R CMD check to run all tests under
# tests/testthat/.

library(testthat)
library(clusteredMSM)

test_check("clusteredMSM")
