% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{print.patp}
\alias{print.patp}
\title{Print Method for patp Objects}
\usage{
\method{print}{patp}(x, digits = max(3L, getOption("digits") - 3L), ...)
}
\arguments{
\item{x}{A \code{patp} object.}

\item{digits}{Integer. Number of significant digits for printing.}

\item{...}{Additional arguments (ignored).}
}
\value{
The object \code{x}, invisibly.
}
\description{
Concise summary of a \code{\link{patp}} fit. For two-sample fits,
includes the K-S statistic and p-value.
}
